@@ -3,33 +3,23 @@ package main
 import (
 	"fmt"
 	"os"
-	"os/exec"
 	"regexp"
 	"strings"
 	"time"
 
 	"github.com/Masterminds/semver/v3"
-	"github.com/otiai10/copy"
 	"github.com/spf13/pflag"
 
 	"github.com/go-task/task/v3/errors"
 )
 
 const (
-	changelogSource    = "CHANGELOG.md"
-	changelogTarget    = "website/docs/changelog.mdx"
-	docsSource         = "website/docs"
-	docsTarget         = "website/versioned_docs/version-latest"
-	schemaSource       = "website/static/next-schema.json"
-	schemaTarget       = "website/static/schema.json"
-	schemaTaskrcSource = "website/static/next-schema-taskrc.json"
-	schemaTaskrcTarget = "website/static/schema-taskrc.json"
+	changelogSource = "CHANGELOG.md"
+	changelogTarget = "website/src/docs/changelog.md"
+	versionFile     = "internal/version/version.txt"
 )
 
-var (
-	changelogReleaseRegex = regexp.MustCompile(`## Unreleased`)
-	versionRegex          = regexp.MustCompile(`(?m)^  "version": "\d+\.\d+\.\d+",$`)
-)
+var changelogReleaseRegex = regexp.MustCompile(`## Unreleased`)
 
 // Flags
 var (
@@ -53,7 +43,7 @@ func release() error {
 		return errors.New("error: expected version number")
 	}
 
-	version, err := getVersion()
+	version, err := getVersion(versionFile)
 	if err != nil {
 		return err
 	}
@@ -71,36 +61,18 @@ func release() error {
 		return err
 	}
 
-	if err := setVersionFile("internal/version/version.txt", version); err != nil {
-		return err
-	}
-
-	if err := setJSONVersion("package.json", version); err != nil {
-		return err
-	}
-
-	if err := setJSONVersion("package-lock.json", version); err != nil {
-		return err
-	}
-
-	if err := docs(); err != nil {
-		return err
-	}
-
-	if err := schema(); err != nil {
+	if err := setVersionFile(versionFile, version); err != nil {
 		return err
 	}
 
 	return nil
 }
 
-func getVersion() (*semver.Version, error) {
-	cmd := exec.Command("git", "describe", "--tags", "--abbrev=0")
-	b, err := cmd.Output()
+func getVersion(filename string) (*semver.Version, error) {
+	b, err := os.ReadFile(filename)
 	if err != nil {
 		return nil, err
 	}
-
 	return semver.NewVersion(strings.TrimSpace(string(b)))
 }
 
@@ -159,37 +131,3 @@ func changelog(version *semver.Version) error {
 func setVersionFile(fileName string, version *semver.Version) error {
 	return os.WriteFile(fileName, []byte(version.String()+"\n"), 0o644)
 }
-
-func setJSONVersion(fileName string, version *semver.Version) error {
-	// Read the JSON file
-	b, err := os.ReadFile(fileName)
-	if err != nil {
-		return err
-	}
-
-	// Replace the version
-	new := versionRegex.ReplaceAllString(string(b), fmt.Sprintf(`  "version": "%s",`, version.String()))
-
-	// Write the JSON file
-	return os.WriteFile(fileName, []byte(new), 0o644)
-}
-
-func docs() error {
-	if err := os.RemoveAll(docsTarget); err != nil {
-		return err
-	}
-	if err := copy.Copy(docsSource, docsTarget); err != nil {
-		return err
-	}
-	return nil
-}
-
-func schema() error {
-	if err := copy.Copy(schemaSource, schemaTarget); err != nil {
-		return err
-	}
-	if err := copy.Copy(schemaTaskrcSource, schemaTaskrcTarget); err != nil {
-		return err
-	}
-	return nil
-}
