@@ -1,6 +1,7 @@
 package task
 
 import (
+	"cmp"
 	"fmt"
 
 	"github.com/go-task/task/v3/internal/hash"
@@ -8,11 +9,7 @@ import (
 )
 
 func (e *Executor) GetHash(t *ast.Task) (string, error) {
-	r := t.Run
-	if r == "" {
-		r = e.Taskfile.Run
-	}
-
+	r := cmp.Or(t.Run, e.Taskfile.Run)
 	var h hash.HashFunc
 	switch r {
 	case "always":
