@@ -1,20 +1,20 @@
 package fingerprint
 
-import "github.com/go-task/task/v3/taskfile"
+import "github.com/go-task/task/v3/taskfile/ast"
 
 // NoneChecker is a no-op Checker.
 // It will always report that the task is not up-to-date.
 type NoneChecker struct{}
 
-func (NoneChecker) IsUpToDate(t *taskfile.Task) (bool, error) {
+func (NoneChecker) IsUpToDate(t *ast.Task) (bool, error) {
 	return false, nil
 }
 
-func (NoneChecker) Value(t *taskfile.Task) (any, error) {
+func (NoneChecker) Value(t *ast.Task) (any, error) {
 	return "", nil
 }
 
-func (NoneChecker) OnError(t *taskfile.Task) error {
+func (NoneChecker) OnError(t *ast.Task) error {
 	return nil
 }
 
