@@ -9,7 +9,7 @@ import (
 
 	"github.com/davecgh/go-spew/spew"
 	"github.com/google/uuid"
-	"gopkg.in/yaml.v3"
+	"go.yaml.in/yaml/v4"
 	"mvdan.cc/sh/v3/shell"
 	"mvdan.cc/sh/v3/syntax"
 
@@ -41,7 +41,6 @@ func init() {
 		"toYaml":       toYaml,
 		"mustToYaml":   mustToYaml,
 		"uuid":         uuid.New,
-		"randInt":      rand.Int,
 		"randIntN":     rand.IntN,
 	}
 
