@@ -1,9 +1,9 @@
 package ast
 
 import (
-	"fmt"
+	"go.yaml.in/yaml/v4"
 
-	"gopkg.in/yaml.v3"
+	"github.com/go-task/task/v3/errors"
 )
 
 type Glob struct {
@@ -13,20 +13,22 @@ type Glob struct {
 
 func (g *Glob) UnmarshalYAML(node *yaml.Node) error {
 	switch node.Kind {
+
 	case yaml.ScalarNode:
 		g.Glob = node.Value
 		return nil
+
 	case yaml.MappingNode:
 		var glob struct {
 			Exclude string
 		}
 		if err := node.Decode(&glob); err != nil {
-			return err
+			return errors.NewTaskfileDecodeError(err, node)
 		}
 		g.Glob = glob.Exclude
 		g.Negate = true
 		return nil
-	default:
-		return fmt.Errorf("yaml: line %d: cannot unmarshal %s into task", node.Line, node.ShortTag())
 	}
+
+	return errors.NewTaskfileDecodeError(nil, node).WithTypeMessage("glob")
 }
